@@ -11,7 +11,9 @@ from jinja2 import StrictUndefined
 from pytz import UTC
 
 from jetstream_config_parser.data_source import DataSourceDefinition
+from jetstream_config_parser.definition import DefinitionSpec, DefinitionSpecSub
 from jetstream_config_parser.function import FunctionsSpec
+from jetstream_config_parser.monitoring import MonitoringSpec
 from jetstream_config_parser.segment import (
     SegmentDataSourceDefinition,
     SegmentDefinition,
@@ -19,7 +21,7 @@ from jetstream_config_parser.segment import (
 
 from .analysis import AnalysisSpec
 from .errors import UnexpectedKeyConfigurationException
-from .experiment import Experiment
+from .experiment import Channel, Experiment
 from .metric import MetricDefinition
 from .outcome import OutcomeSpec
 from .util import TemporaryDirectory
@@ -36,14 +38,29 @@ class Config:
     """Represent an external config file."""
 
     slug: str
-    spec: AnalysisSpec
+    spec: DefinitionSpecSub
     last_modified: dt.datetime
     is_private: bool = False
 
     def validate(self, configs: "ConfigCollection", experiment: Experiment) -> None:
-        spec = AnalysisSpec.default_for_experiment(experiment, configs)
-        spec.merge(self.spec)
-        spec.resolve(experiment, configs)
+        if isinstance(self.spec, AnalysisSpec):
+            analysis_spec = AnalysisSpec.default_for_experiment(experiment, configs)
+            analysis_spec.merge(self.spec)
+            resolved = analysis_spec.resolve(experiment, configs)
+            # private configs need to override the default dataset
+            if self.is_private and resolved.experiment.dataset_id is None:
+                raise ValueError("dataset_id needs to be explicitly set for private experiments")
+        elif isinstance(self.spec, MonitoringSpec):
+            monitoring_spec = MonitoringSpec.default_for_platform_or_type(
+                (experiment.app_name if experiment else self.spec.project.platform)
+                or "firefox_desktop",
+                configs,
+            )
+            if experiment and experiment.is_rollout:
+                rollout_spec = MonitoringSpec.default_for_platform_or_type("rollout", configs)
+                monitoring_spec.merge(rollout_spec)
+            monitoring_spec.merge(self.spec)
+            monitoring_spec.resolve(experiment, configs)
 
 
 def validate_config_settings(config_file: Path) -> None:
@@ -64,6 +81,8 @@ def validate_config_settings(config_file: Path) -> None:
     config = toml.loads(config_file.read_text())
 
     optional_core_config_keys = (
+        "project",
+        "population",
         "metrics",
         "experiment",
         "segments",
@@ -71,6 +90,8 @@ def validate_config_settings(config_file: Path) -> None:
         "friendly_name",
         "description",
         "parameters",
+        "alerts",
+        "dimensions",
     )
 
     core_config_keys_specified = config.keys()
@@ -109,6 +130,7 @@ class DefaultConfig(Config):
             start_date=dt.datetime.now(UTC),
             proposed_enrollment=14,
             app_name=self.slug,
+            channel=Channel.NIGHTLY,
         )
         spec = AnalysisSpec.default_for_experiment(dummy_experiment, configs)
         spec.merge(self.spec)
@@ -138,6 +160,7 @@ class Outcome:
             start_date=dt.datetime.now(UTC),
             proposed_enrollment=14,
             app_name=self.platform,
+            channel=Channel.NIGHTLY,
         )
 
         spec = AnalysisSpec.default_for_experiment(dummy_experiment, configs)
@@ -167,12 +190,20 @@ class DefinitionConfig(Config):
             start_date=dt.datetime.now(UTC),
             proposed_enrollment=14,
             app_name=self.platform,
+            channel=Channel.NIGHTLY,
         )
 
-        self.spec.resolve(dummy_experiment, configs)
+        if not isinstance(self.spec, DefinitionSpec):
+            # this should not happen
+            raise ValueError("Incorrect result type when parsing definition config")
+
+        analysis_spec = AnalysisSpec.from_definition_spec(self.spec)
+        analysis_spec.resolve(dummy_experiment, configs)
 
 
-def entity_from_path(path: Path) -> Union[Config, Outcome, DefaultConfig, DefinitionConfig]:
+def entity_from_path(
+    path: Path, is_private: bool = False
+) -> Union[Config, Outcome, DefaultConfig, DefinitionConfig]:
     is_outcome = path.parent.parent.name == OUTCOMES_DIR
     is_default_config = path.parent.name == DEFAULTS_DIR
     is_definition_config = path.parent.name == DEFINITIONS_DIR
@@ -185,25 +216,49 @@ def entity_from_path(path: Path) -> Union[Config, Outcome, DefaultConfig, Defini
     if is_outcome:
         platform = path.parent.name
         spec = OutcomeSpec.from_dict(config_dict)
-        return Outcome(slug=slug, spec=spec, platform=platform, commit_hash=None)
-    elif is_default_config:
-        return DefaultConfig(
-            slug=slug,
-            spec=AnalysisSpec.from_dict(config_dict),
-            last_modified=dt.datetime.fromtimestamp(path.stat().st_mtime, UTC),
+        return Outcome(
+            slug=slug, spec=spec, platform=platform, commit_hash=None, is_private=is_private
         )
+    elif is_default_config:
+        if "project" in config_dict:
+            # config is from opmon
+            return DefaultConfig(
+                slug=slug,
+                spec=MonitoringSpec.from_dict(config_dict),
+                last_modified=dt.datetime.fromtimestamp(path.stat().st_mtime, UTC),
+                is_private=is_private,
+            )
+        else:
+            return DefaultConfig(
+                slug=slug,
+                spec=AnalysisSpec.from_dict(config_dict),
+                last_modified=dt.datetime.fromtimestamp(path.stat().st_mtime, UTC),
+                is_private=is_private,
+            )
     elif is_definition_config:
         return DefinitionConfig(
             slug=slug,
-            spec=AnalysisSpec.from_dict(config_dict),
+            spec=DefinitionSpec.from_dict(config_dict),
             last_modified=dt.datetime.fromtimestamp(path.stat().st_mtime, UTC),
             platform=slug,
+            is_private=is_private,
+        )
+
+    if "project" in config_dict:
+        # config is from opmon
+        return Config(
+            slug=slug,
+            spec=MonitoringSpec.from_dict(config_dict),
+            last_modified=dt.datetime.fromtimestamp(path.stat().st_mtime, UTC),
+            is_private=is_private,
+        )
+    else:
+        return Config(
+            slug=slug,
+            spec=AnalysisSpec.from_dict(config_dict),
+            last_modified=dt.datetime.fromtimestamp(path.stat().st_mtime, UTC),
+            is_private=is_private,
         )
-    return Config(
-        slug=slug,
-        spec=AnalysisSpec.from_dict(config_dict),
-        last_modified=dt.datetime.fromtimestamp(path.stat().st_mtime, UTC),
-    )
 
 
 @attr.s(auto_attribs=True)
@@ -228,21 +283,29 @@ class ConfigCollection:
         """Pull in external config files."""
         # download files to tmp directory
         with TemporaryDirectory() as tmp_dir:
-            repo = Repo.clone_from(repo_url or cls.repo_url, tmp_dir)
+            if repo_url is not None and Path(repo_url).exists() and Path(repo_url).is_dir():
+                repo = Repo(repo_url)
+                tmp_dir = Path(repo_url)
+            else:
+                repo = Repo.clone_from(repo_url or cls.repo_url, tmp_dir)
 
             external_configs = []
 
             for config_file in tmp_dir.glob("*.toml"):
                 last_modified = next(repo.iter_commits("main", paths=config_file)).committed_date
-                analysis_spec = AnalysisSpec.from_dict(toml.load(config_file))
-                analysis_spec.experiment.is_private = (
-                    analysis_spec.experiment.is_private or is_private
-                )
+                config_json = toml.load(config_file)
+
+                if "project" in config_json:
+                    # opmon spec
+                    spec: DefinitionSpecSub = MonitoringSpec.from_dict(config_json)
+                else:
+                    spec = AnalysisSpec.from_dict(config_json)
+                    spec.experiment.is_private = spec.experiment.is_private or is_private
 
                 external_configs.append(
                     Config(
                         config_file.stem,
-                        analysis_spec,
+                        spec,
                         UTC.localize(dt.datetime.utcfromtimestamp(last_modified)),
                         is_private=is_private,
                     )
@@ -268,10 +331,19 @@ class ConfigCollection:
                     repo.iter_commits("main", paths=default_config_file)
                 ).committed_date
 
+                default_config_json = toml.load(default_config_file)
+
+                if "project" in config_json:
+                    # opmon spec
+                    spec = MonitoringSpec.from_dict(default_config_json)
+                else:
+                    spec = AnalysisSpec.from_dict(default_config_json)
+                    spec.experiment.is_private = spec.experiment.is_private or is_private
+
                 default_configs.append(
                     DefaultConfig(
                         default_config_file.stem,
-                        AnalysisSpec.from_dict(toml.load(default_config_file)),
+                        spec,
                         UTC.localize(dt.datetime.utcfromtimestamp(last_modified)),
                         is_private=is_private,
                     )
@@ -286,7 +358,7 @@ class ConfigCollection:
                 definitions.append(
                     DefinitionConfig(
                         definitions_config_file.stem,
-                        AnalysisSpec.from_dict(toml.load(definitions_config_file)),
+                        DefinitionSpec.from_dict(toml.load(definitions_config_file)),
                         UTC.localize(dt.datetime.utcfromtimestamp(last_modified)),
                         platform=definitions_config_file.stem,
                         is_private=is_private,
@@ -304,7 +376,7 @@ class ConfigCollection:
         cls, repo_urls: Optional[List[str]] = None, is_private: bool = False
     ) -> "ConfigCollection":
         """Load configs from the provided repos."""
-        if repo_urls is None or len(repo_urls) > 0:
+        if repo_urls is None or len(repo_urls) < 1:
             return ConfigCollection.from_github_repo()
 
         configs = None
@@ -329,17 +401,34 @@ class ConfigCollection:
         """Return the spec for a specific experiment."""
         for config in self.configs:
             if config.slug == slug:
-                return config.spec
+                if isinstance(config.spec, AnalysisSpec):
+                    return config.spec
 
         return None
 
-    def get_platform_defaults(self, platform: str) -> Optional[AnalysisSpec]:
+    def spec_for_project(self, slug: str) -> Optional[MonitoringSpec]:
+        """Return the spec for a specific project."""
+        for config in self.configs:
+            if config.slug == slug:
+                if isinstance(config.spec, MonitoringSpec):
+                    return config.spec
+
+        return None
+
+    def get_platform_defaults(self, platform: str) -> Optional[DefinitionSpecSub]:
         for default in self.defaults:
             if platform == default.slug:
                 return default.spec
 
         return None
 
+    def get_platform_definitions(self, platform: str) -> Optional[DefinitionSpecSub]:
+        for definition in self.definitions:
+            if platform == definition.slug:
+                return definition.spec
+
+        return None
+
     def get_metric_definition(self, slug: str, app_name: str) -> Optional[MetricDefinition]:
         for definition in self.definitions:
             if app_name == definition.platform:
@@ -367,21 +456,23 @@ class ConfigCollection:
     ) -> Optional[SegmentDataSourceDefinition]:
         for definition in self.definitions:
             if app_name == definition.platform:
-                for (
-                    segment_source_slug,
-                    segment_source,
-                ) in definition.spec.segments.data_sources.items():
-                    if segment_source_slug == slug:
-                        return segment_source
+                if not isinstance(definition.spec, MonitoringSpec):
+                    for (
+                        segment_source_slug,
+                        segment_source,
+                    ) in definition.spec.segments.data_sources.items():
+                        if segment_source_slug == slug:
+                            return segment_source
 
         return None
 
     def get_segment_definition(self, slug: str, app_name: str) -> Optional[SegmentDefinition]:
         for definition in self.definitions:
             if app_name == definition.platform:
-                for segment_slug, segment in definition.spec.segments.definitions.items():
-                    if segment_slug == slug:
-                        return segment
+                if not isinstance(definition.spec, MonitoringSpec):
+                    for segment_slug, segment in definition.spec.segments.definitions.items():
+                        if segment_slug == slug:
+                            return segment
 
         return None
 
