@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Any, Dict, Optional
+from typing import TYPE_CHECKING, Any, Dict, Optional, Union
 
 import attr
 
@@ -6,8 +6,9 @@ from jetstream_config_parser.errors import DefinitionNotFound
 
 if TYPE_CHECKING:
     from jetstream_config_parser.config import ConfigCollection
-    from .analysis import AnalysisSpec
     from .experiment import ExperimentConfiguration
+    from .definition import DefinitionSpecSub
+    from .project import ProjectConfiguration
 
 from .util import converter
 
@@ -53,6 +54,7 @@ class DataSource:
     client_id_column = attr.ib(default="client_id", type=str)
     submission_date_column = attr.ib(default="submission_date", type=str)
     default_dataset = attr.ib(default=None, type=Optional[str])
+    build_id_column = attr.ib(default="SAFE.SUBSTR(application.build_id, 0, 8)", type=str)
 
     EXPERIMENT_COLUMN_TYPES = (None, "simple", "native", "glean")
 
@@ -92,16 +94,14 @@ class DataSourceReference:
 
     def resolve(
         self,
-        spec: "AnalysisSpec",
-        experiment: "ExperimentConfiguration",
+        spec: "DefinitionSpecSub",
+        conf: Union["ExperimentConfiguration", "ProjectConfiguration"],
         configs: "ConfigCollection",
     ) -> DataSource:
         if self.name in spec.data_sources.definitions:
             return spec.data_sources.definitions[self.name].resolve(spec)
 
-        data_source_definition = configs.get_data_source_definition(
-            self.name, experiment.experiment.app_name
-        )
+        data_source_definition = configs.get_data_source_definition(self.name, conf.app_name)
         if data_source_definition is None:
             raise DefinitionNotFound(f"No default definition for data source '{self.name}' found")
         return data_source_definition.resolve(spec)
@@ -122,8 +122,9 @@ class DataSourceDefinition:
     client_id_column: Optional[str] = "client_id"
     submission_date_column: Optional[str] = "submission_date"
     default_dataset: Optional[str] = None
+    build_id_column: str = "SAFE.SUBSTR(application.build_id, 0, 8)"
 
-    def resolve(self, spec: "AnalysisSpec") -> DataSource:
+    def resolve(self, spec: "DefinitionSpecSub") -> DataSource:
         params: Dict[str, Any] = {"name": self.name, "from_expression": self.from_expression}
         # Allow mozanalysis to infer defaults for these values:
         for k in (
@@ -131,6 +132,7 @@ class DataSourceDefinition:
             "client_id_column",
             "submission_date_column",
             "default_dataset",
+            "build_id_column",
         ):
             v = getattr(self, k)
             if v:
